<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Teknisa\MAN\Services;
use Teknisa\MAN\Utilities;

class CancelamentoServico extends CrudWithParameterBag {
    protected $dataSourceName = '';
    protected $parameterBagColumns = array('NRORG', 'CDFILIAL', 'DATAINI', 'DATAFIN', 'CDLOJA');
    protected $CancelamentoServicoService;
    protected $utilService;

    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag,  Utilities\Util $utilService,  Services\CancelamentoServico $CancelamentoServicoService) {
        parent::__construct($dataSourceManager, $parameterBag);
        $this->utilService = $utilService;
        $this->CancelamentoServicoService = $CancelamentoServicoService;
    }

    private function setTCDandCDcondition(&$conditions, $key, $keyName) {
        if( !array_key_exists($key, $conditions) ) {
            $conditions['T'.$keyName] = 'T';    
            $conditions[$keyName] = null;    
        } else {
            
            $conditions[$keyName] = '_'.implode('_', $conditions[$keyName] ).'_';
            $conditions['T'.$keyName] = 'F';
            if($key !== $keyName) {
                unset($conditions[$keyName]);
            }
        }
        
    }

    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        $result = array();
        ini_set('memory_limit', '500M');
        
        $conditions = $this->utilService->getParamsAsArray($request);
        
        if (!empty($conditions['CDLOJAFILIAL'])){
             $conditions['CDLOJA']=$conditions['CDLOJAFILIAL'];
            }

    if(isset($conditions['CDFILIAL'])){
        try {
            
            $conditions['__is_report'] = ($request->getFilterCriteria()->getPage() === null); 
            if( array_key_exists('DTENTRVENDA', $conditions) ) {
                $conditions['DATAINI'] = $conditions['DTENTRVENDA'][0];
                $conditions['DATAFIN'] = $conditions['DTENTRVENDA'][1];
                unset($conditions['DTENTRVENDA']);
            }

            if( array_key_exists('LABELFILIAL', $conditions) ) {
                $conditions['CDFILIAL'] = $conditions['LABELFILIAL'];
                unset($conditions['LABELFILIAL']);
            }
            if( array_key_exists('LABELLOJA', $conditions) ) {
                $conditions['CDLOJA'] = $conditions['LABELLOJA'];
                unset($conditions['LABELLOJA']);
            }
            if( array_key_exists('GARCONFORM', $conditions) ) {
                $conditions['CDVENDEDOR'] = implode('_', $conditions['GARCONFORM']);
                $conditions['TCDVENDEDOR'] = 'F';
                unset($conditions['GARCONFORM']);
            }
            if(!is_array($conditions['CDFILIAL'])){
                $filial = array(
                    $conditions['CDFILIAL']
                );
                $conditions['CDFILIAL'] = $filial;
            }
            
            $this->setTCDandCDcondition($conditions, 'CDFILIAL', 'CDFILIAL');
            $this->setTCDandCDcondition($conditions, 'CDLOJA', 'CDLOJA');
            $result = $this->CancelamentoServicoService->getCancelamentoServico($conditions);
            $response->addDataSet(new DataSet ('vnd55005_relCancelamentoServico', $result));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    else{
        return null;
    }
    }
}