<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\Controller\CrudWithParameterBag;

class RelSaldoConsumidor extends CrudWithParameterBag {
    
    protected $dataSourceName = "vnd07400_relSaldoConsumidor";      
    protected $parameterBagColumns        = array ('TCDCONSUMIDOR', 'CDCONSUMIDOR', 'TCDTIPOCONS', 'CDTIPOCONS', 'CDCLIENTE',  'TCDCLIENTE', 'DTLANCINI', 'NRORG', 'NMFILIAL', 'CDOPERADOR', 'CDFILIAL', 'CDCCUSCLIE', 'TCDCCUSCLIE');
              
    public function __construct ($crudService, $parameterBag, Manager $dataSourceManager, $utilService) {
        $this->crudService              = $crudService;
        $this->parameterBag             = $parameterBag;
        $this->dataSourceManager        = $dataSourceManager;
        $this->utilService              = $utilService;
    }
    
    public function findRel (DTO\Request\Filter $request, DTO\Response $response) {
        
        $conditions = $this->buildParams($this->utilService->getParamsAsArray($request));
        $dataSourceFilter = array();
        foreach($conditions as $key => $value) {
            if(!is_array($value)){
                $dataSourceFilter[] = $condition = array(
                    "columnName" => $key,
                    "operator"=> "=",
                    "value"=> $value
                );
            }
        }
        
        $requestDataSourceFilter = $request->getFilterCriteria()->getConditions();
        foreach($requestDataSourceFilter as $filter) {
            if($filter['operator'] === 'MAPPED_LIKE_ALL') {
                array_push($dataSourceFilter, $filter);
            }
        }
        
        $newRequest = new DTO\Request\Filter(
            new FilterCriteria(
                $this->dataSourceName,
                $dataSourceFilter,
                $request->getFilterCriteria()->getPage(),
                $request->getFilterCriteria()->getPageSize()
            ),
            $request->getMethod(),
            $request->getRoutePath(),
            $request->getUserId()
        );
        $this->parameterBagColumns = $this->parameterBagColumns;
        parent::find($newRequest, $response);
    }
    
    public function buildParams($conditions){
        
        if(!array_key_exists('CDCLIENTE', $conditions)) {
            $conditions['CDCLIENTE'] = '';
            $conditions['TCDCLIENTE'] = 'T';
        } else {
            $conditions['CDCLIENTE'] = implode('_', $conditions['CDCLIENTE']);
            $conditions['TCDCLIENTE'] = '';
        }
        
        if(!array_key_exists('CDCONSUMIDOR', $conditions)) {
            $conditions['CDCONSUMIDOR'] = '';
            $conditions['TCDCONSUMIDOR'] = 'T';
        } else {
            $conditions['CDCONSUMIDOR'] = implode('_', $conditions['CDCONSUMIDOR']);
            $conditions['TCDCONSUMIDOR'] = '';
        }
        
        if(!array_key_exists('CDTIPOCONS', $conditions)) {
            $conditions['CDTIPOCONS'] = '';
            $conditions['TCDTIPOCONS'] = 'T';
        } else {
            $conditions['CDTIPOCONS'] = implode('_', $conditions['CDTIPOCONS']);
            $conditions['TCDTIPOCONS'] = '';
        }
        
        if(!array_key_exists('CDCCUSCLIE', $conditions)) {
            $conditions['CDCCUSCLIE'] = '';
            $conditions['TCDCCUSCLIE'] = 'T';
        } else {
            $conditions['CDCCUSCLIE'] = implode('_', $conditions['CDCCUSCLIE']);
            $conditions['TCDCCUSCLIE'] = '';
        }
        
        return $conditions;
    }
}